# Short Notes documenting the RStudio server at iDiv

## Access Web-IDE of RStudio
1. [https://rstudio.idiv.de](https://rstudio.idiv.de)
1. use your iDiv username and password to login
1. please remember to end your session when you have finished your current calculations (red button upper right)


## ssh access
You can only reach the server from the internal network, i.e. if you are connected via VPN or cable at iDiv. Note that the internal name is rstudio1 instead of rstudio!

### Linux
From a terminal run

```bash
ssh rstudio1.idiv.de
```

## Data organisation
Currently there are three important places for you on the server:

1. /homes/$USER your home directory 
2. /data place any larger files you want to work with here
3. /home/$USER/winhome a mounting point for your network home directory

### Home directory
When you log in either via https or ssh this is usually the first place where you end up. Your home directory can be abbreviated by "~/". There is not a lot of space here, so do not place any larger data here. RStudio has the ugly not configurable habit to write quite some temporary data here (e.g. cached plots and suspended sessions), so please make sure that you clean up occasionally. It is a good place for your scripts.

RStudio stores several files like suspended sessions, graph history etc. in `~/.rstudio`. This folder is purged every 90 days to remove "forgotten" suspended sessions and reduce wasted space.

### /data
You can create your own directories here and place data inside. By default others can read the directories you created here, but not write in them. If you need any special permission let us know via it-support@idiv.de.

### idiv group shares
If you are part of an iDiv group you can access your group share on the rstudio server at `/data/GROUPNAME-group-share/`. If your group share is not available yet please contact [it-support@idiv.de](mailto:it-support@idiv.de).


## network home
This is about \\idiv.de\public\homes. To make it available on the rstudio server you need to get active. Log in via ssh and run
```
su - $USER
```
You will be asked to enter your password again and afterwards your network home will be available at `~/winhome`. However, it will only stay mounted until you log out. If you have any longer running jobs you might want to consider either moving stuff from the ~/winhome to /data or open a [tmux](tmux.md) session from which you detach (Ctrl+b, d) before you disconnect.


## Packages
Many R packages are installed already via the system's package management and many more are available via the same track. This is the preferred way to install R packages, as it avoids duplicate installations per user, removes the need for manual package updates and helps that underlying libraries and packages are compatible with each other. Currently there are >3500 packages installed—check with `installed.packages()` for more details.

Of course you can still install packages via R's own functions (install.packages, devtools, …) if there is the need for it. Long term please drop a note to it-suppot@idiv.de so that we can install the package via the system.

- https://github.com/eddelbuettel/rcppapt <- not yet implemente: 


## Other servers with R
There are some other servers which have R and RStudio (desktop version) installed, but support for R on those is limited. This means you might frequently encounter outdated versions of R and associated packages.

- idivgis01.idiv.de Biocon windows 2012r2 terminal server with gpu but restricted access
- idivts6.idiv.de Biocon windows 2012r2 terminal server but restricted access
- idivts7.idiv.de windows 2012r2 terminal server
- idivts8.idiv.de windows 2012r2 terminal server